@@ -52,6 +52,9 @@ WUTDialog::WUTDialog( QWidget *parent, bool _session, GeoLocation *_geo, KStarsD
         EveningFlag(0),
         timer(NULL)
 {
+#ifdef Q_OS_OSX
+        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+#endif
     WUT = new WUTDialogUI( this );
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -87,7 +90,7 @@ WUTDialog::WUTDialog( QWidget *parent, bool _session, GeoLocation *_geo, KStarsD
     QString sGeo = geo->translatedName();
     if ( ! geo->translatedProvince().isEmpty() ) sGeo += ", " + geo->translatedProvince();
     sGeo += ", " + geo->translatedCountry();
-    WUT->LocationLabel->setText( i18n( "at %1", sGeo ) );    
+    WUT->LocationLabel->setText( i18n( "at %1", sGeo ) );
     WUT->DateLabel->setText( i18n( "The night of %1", QLocale().toString( Evening.date(), QLocale::LongFormat ) ) );
     m_Mag = 10.0;
     WUT->MagnitudeEdit->setValue( m_Mag );
@@ -120,7 +123,7 @@ void WUTDialog::makeConnections() {
 void WUTDialog::initCategories() {
     m_Categories << i18n( "Planets" ) << i18n( "Stars" )
     << i18n( "Nebulae" ) << i18n( "Galaxies" )
-    << i18n( "Star Clusters" ) << i18n( "Constellations" ) 
+    << i18n( "Star Clusters" ) << i18n( "Constellations" )
     << i18n( "Asteroids" ) << i18n( "Comets" );
 
     foreach ( const QString &c, m_Categories )
@@ -153,7 +156,7 @@ void WUTDialog::init() {
     //check to see if Sun is circumpolar
     KSNumbers *num = new KSNumbers( UT0.djd() );
     KSNumbers *oldNum = new KSNumbers( data->ut().djd() );
-    dms LST = geo->GSTtoLST( T0.gst() );
+    CachingDms LST = geo->GSTtoLST( T0.gst() );
 
     oSun->updateCoords( num, true, geo->lat(), &LST, true );
     if ( oSun->checkCircumpolar( geo->lat() ) ) {
@@ -484,7 +487,7 @@ void WUTDialog::slotObslist()
 
 void WUTDialog::slotChangeDate() {
 
-    // Set the time T0 to the evening of today. This will make life easier for the user, who most probably 
+    // Set the time T0 to the evening of today. This will make life easier for the user, who most probably
     // wants to see what's up on the night of some date, rather than the night of the previous day
     T0.setTime( QTime( 18, 0, 0 ) ); // 6 PM
 
